@@ -1,17 +1,22 @@
 // Print the continued fraction of a real number.
 
 // We work with real numbers and integers.
-#include <cl_real.h>
-#include <cl_integer.h>
+#include <cln/real.h>
+#include <cln/integer.h>
 
 // We do I/O.
-#include <cl_io.h>
-#include <cl_integer_io.h>
+#include <cln/io.h>
+#include <cln/integer_io.h>
+
+using namespace std;
+using namespace cln;
 
 // Our private error handling: return to the main program.
 #include <setjmp.h>
 jmp_buf restartpoint;
-void cl_abort (void) { longjmp(restartpoint,1); }
+namespace cln {
+	void cl_abort (void) { longjmp(restartpoint,1); }
+}
 
 int main (int argc, char* argv[])
 {
@@ -23,23 +28,23 @@ int main (int argc, char* argv[])
 		cl_R x = arg;
 		// Check sign.
 		if (minusp(x)) {
-			fprint(cl_stdout, "-");
+			cout << '-';
 			x = -x;
 		}
-		fprint(cl_stdout, "[");
+		cout << "[";
 		const char* separator = "; ";
 		for (;;) {
 			// Split x into integral and fractional part.
 			cl_R_div_t x_split = floor2(x);
-			fprint(cl_stdout, x_split.quotient);
+			cout << x_split.quotient;
 			x = x_split.remainder;
 			if (zerop(x))
 				break;
-			fprint(cl_stdout, separator);
+			cout << separator;
 			separator = ", ";
 			// Invert x.
 			x = recip(x);
 		}
-		fprint(cl_stdout, "]\n");
+		cout << ']' << endl;
 	}
 }
