@@ -4,18 +4,20 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_complex.h"
+#include "cln/complex.h"
 
 
 // Implementation.
 
 #include "cl_C.h"
-#include "cl_real.h"
+#include "cln/real.h"
 
 #undef MAYBE_INLINE
 #define MAYBE_INLINE inline
 #include "cl_C_abs_aux.cc"
 
+namespace cln {
+
 const cl_R abs (const cl_N& x)
 {
 // Methode:
@@ -29,3 +31,5 @@ const cl_R abs (const cl_N& x)
 		return abs(x);
 	}
 }
+
+}  // namespace cln
