@@ -3,6 +3,8 @@
 #ifndef _CL_IEEE_H
 #define _CL_IEEE_H
 
+namespace cln {
+
 // To make sure that cl_ieee.cc is linked in.
 // NEED_IEEE_FLOATS()
 #if (defined(linux) || defined(__linux)) // only needed on Linux
@@ -14,4 +16,6 @@
 #endif
 extern int cl_ieee_module;
 
+}  // namespace cln
+
 #endif /* _CL_IEEE_H */
