@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_dfloat.h"
+#include "cln/dfloat.h"
 
 
 // Implementation.
 
 #include "cl_DF.h"
 
+namespace cln {
+
 MAYBE_INLINE
 cl_boolean minusp (const cl_DF& x)
 {
@@ -20,3 +22,5 @@ cl_boolean minusp (const cl_DF& x)
 	return (cl_boolean) ((sint32)TheDfloat(x)->dfloat_value_semhi < 0);
 #endif
 }
+
+}  // namespace cln
