@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_dfloat.h"
+#include "cln/dfloat.h"
 
 
 // Implementation.
@@ -12,6 +12,8 @@
 #include "cl_DF.h"
 #include "cl_I.h"
 
+namespace cln {
+
 MAYBE_INLINE
 const cl_idecoded_float integer_decode_float (const cl_DF& x)
 {
@@ -41,3 +43,5 @@ const cl_idecoded_float integer_decode_float (const cl_DF& x)
 	       );
 #endif
 }
+
+}  // namespace cln
