@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_ffloat.h"
+#include "cln/ffloat.h"
 
 
 // Implementation.
@@ -12,8 +12,10 @@
 #include "cl_N.h"
 #include "cl_FF.h"
 
+namespace cln {
+
 MAYBE_INLINE
-uint32 cl_equal_hashcode (const cl_FF& x)
+uint32 equal_hashcode (const cl_FF& x)
 {
 	var cl_signean sign;
 	var sintL exp;
@@ -22,3 +24,5 @@ uint32 cl_equal_hashcode (const cl_FF& x)
 	var uint32 msd = mant << (32-(FF_mant_len+1));
 	return equal_hashcode_low(msd,exp,sign);
 }
+
+}  // namespace cln
