@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_ffloat.h"
+#include "cln/ffloat.h"
 
 
 // Implementation.
 
 #include "cl_FF.h"
 
+namespace cln {
+
 MAYBE_INLINE
 sintL float_exponent (const cl_FF& x)
 {
@@ -18,3 +20,5 @@ sintL float_exponent (const cl_FF& x)
 	if (uexp==0) { return 0; }
 	return (sintL)(uexp - FF_exp_mid);
 }
+
+}  // namespace cln
