@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_lfloat.h"
+#include "cln/lfloat.h"
 
 
 // Implementation.
@@ -13,6 +13,8 @@
 #include "cl_LF_impl.h"
 #include "cl_DS.h"
 
+namespace cln {
+
 const cl_LF operator- (const cl_LF& x)
 {
 // Methode:
@@ -26,3 +28,5 @@ const cl_LF operator- (const cl_LF& x)
           return mx;
         }
 }
+
+}  // namespace cln
