@@ -8,9 +8,11 @@
 
 // Implementation.
 
-#include "cl_sfloat.h"
-#include "cl_io.h"
-#include "cl_float_io.h"
+#include "cln/sfloat.h"
+#include "cln/io.h"
+#include "cln/float_io.h"
+
+namespace cln {
 
 static void dprint (cl_heap* pointer)
 {
@@ -21,5 +23,7 @@ static void dprint (cl_heap* pointer)
 AT_INITIALIZATION(dprint_SF)
 { cl_register_type_printer(cl_class_sfloat,dprint); }
 
-// This dummy links in this module when <cl_sfloat.h> requires it.
+// This dummy links in this module when <cln/sfloat.h> requires it.
 int cl_SF_debug_module;
+
+}  // namespace cln
