@@ -1,10 +1,10 @@
-// cl_pi().
+// pi().
 
 // General includes.
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
@@ -13,12 +13,16 @@
 #include "cl_F_tran.h"
 #include "cl_LF.h"
 
-const cl_F cl_pi (const cl_F& y)
+namespace cln {
+
+const cl_F pi (const cl_F& y)
 {
 	floattypecase(y
 	,	return cl_SF_pi;
 	,	return cl_FF_pi;
 	,	return cl_DF_pi;
-	,	return cl_pi(TheLfloat(y)->len);
+	,	return pi(TheLfloat(y)->len);
 	);
 }
+
+}  // namespace cln
