@@ -1,10 +1,10 @@
-// cl_pi().
+// pi().
 
 // General includes.
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_float.h"
+#include "cln/float.h"
 
 
 // Implementation.
@@ -12,12 +12,16 @@
 #include "cl_F.h"
 #include "cl_F_tran.h"
 
-const cl_F cl_pi (cl_float_format_t f)
+namespace cln {
+
+const cl_F pi (float_format_t f)
 {
 	floatformatcase((uintL)f
 	,	return cl_SF_pi;
 	,	return cl_FF_pi;
 	,	return cl_DF_pi;
-	,	return cl_pi(len);
+	,	return pi(len);
 	);
 }
+
+}  // namespace cln
