@@ -3,10 +3,14 @@
 #ifndef _CL_I_ASH_H
 #define _CL_I_ASH_H
 
-#include "cl_number.h"
-#include "cl_integer_class.h"
+#include "cln/number.h"
+#include "cln/integer_class.h"
 #include "cl_macros.h"
 
+namespace cln {
+
 nonreturning_function(extern, cl_ash_error, (const cl_I& badamount));
 
+}  // namespace cln
+
 #endif /* _CL_I_ASH_H */
