@@ -3,14 +3,15 @@
 #ifndef _CL_I_H
 #define _CL_I_H
 
-#include "cl_number.h"
-#include "cl_integer.h"
+#include "cln/number.h"
+#include "cln/integer.h"
 #include "cl_macros.h"
-#include "cl_malloc.h"
-#include "cl_abort.h"
+#include "cln/malloc.h"
+#include "cln/abort.h"
 #include "cl_offsetof.h"
 #include "cl_DS.h"
 
+namespace cln {
 
 // maximal needed length of a digit sequence for a fixnum
   #define FN_maxlength  ceiling(cl_value_len,intDsize)
@@ -52,7 +53,7 @@ inline cl_heap_bignum* TheBignum (const cl_number& obj)
 
 inline cl_heap_bignum* allocate_bignum (unsigned int length)
 {
-	cl_heap_bignum* p = (cl_heap_bignum*) cl_malloc_hook(offsetofa(cl_heap_bignum,data)+sizeof(uintD)*length);
+	cl_heap_bignum* p = (cl_heap_bignum*) malloc_hook(offsetofa(cl_heap_bignum,data)+sizeof(uintD)*length);
 	p->refcount = 1;
 	p->type = &cl_class_bignum;
 	p->length = length;
@@ -89,7 +90,7 @@ inline cl_boolean bignump (const cl_I& x)
 inline cl_boolean minusp (const cl_I& x)
 {
 	if (fixnump(x))
-		// This assumes cl_value_shift + cl_value_len == cl_word_size.
+		// This assumes cl_value_shift + cl_value_len == cl_pointer_size.
 		return (cl_boolean)((cl_sint) x.word < 0);
 	else
 		return (cl_boolean)((sintD)mspref(arrayMSDptr(TheBignum(x)->data,TheBignum(x)->length),0) < 0);
@@ -116,7 +117,7 @@ inline cl_boolean eq (const cl_I& x, sint32 y)
 // < ergebnis: der Wert des Fixnum als 32-Bit-Zahl.
 inline uint32 FN_to_UL (const cl_I& x)
 {
-	// This assumes cl_value_shift + cl_value_len == cl_word_size.
+	// This assumes cl_value_shift + cl_value_len == cl_pointer_size.
 	return (cl_uint)(x.word) >> cl_value_shift;
 }
 
@@ -126,7 +127,7 @@ inline uint32 FN_to_UL (const cl_I& x)
 // < ergebnis: der Wert des Fixnum als 32-Bit-Zahl.
 inline sint32 FN_to_L (const cl_I& x)
 {
-	// This assumes cl_value_shift + cl_value_len == cl_word_size.
+	// This assumes cl_value_shift + cl_value_len == cl_pointer_size.
 	return (cl_sint)(x.word) >> cl_value_shift;
 }
 
@@ -146,7 +147,7 @@ inline sint32 FN_to_L (const cl_I& x)
 // < ergebnis: der Wert des Fixnum als 64-Bit-Zahl.
 inline sint64 FN_to_Q (const cl_I& x)
 {
-	// This assumes cl_value_shift + cl_value_len == cl_word_size.
+	// This assumes cl_value_shift + cl_value_len == cl_pointer_size.
 	return (cl_sint)(x.word) >> cl_value_shift;
 }
 
@@ -362,7 +363,7 @@ inline uint64 pFN_maxlength_digits_at (const uintD* ptr)
 
 inline sintD FN_MSD (cl_uint word)
 {
-	// This assumes cl_value_shift + cl_value_len == cl_word_size.
+	// This assumes cl_value_shift + cl_value_len == cl_pointer_size.
 	return (cl_sint)word >> (cl_value_shift + (FN_maxlength-1)*intDsize);
 }
 
@@ -629,7 +630,7 @@ inline cl_boolean bignump (const cl_FN& x)
 
 inline cl_boolean minusp (const cl_FN& x)
 {
-	// This assumes cl_value_shift + cl_value_len == cl_word_size.
+	// This assumes cl_value_shift + cl_value_len == cl_pointer_size.
 	return (cl_boolean)((cl_sint) x.word < 0);
 }
 
@@ -656,4 +657,6 @@ inline cl_boolean minusp (const cl_BN& x)
 inline cl_boolean zerop (const cl_BN& x)
 	{ unused x; return cl_false; }
 
+}  // namespace cln
+
 #endif /* _CL_I_H */
