@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
 
 #include "cl_I.h"
 
+namespace cln {
+
 const cl_I_div_t floor2 (const cl_I& x, const cl_I& y)
 {
 // Methode:
@@ -33,3 +35,5 @@ const cl_I_div_t floor2 (const cl_I& x, const cl_I& y)
     { q = -q; }
   return q_r;
 }
+
+}  // namespace cln
