@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
 
 #include "cl_I.h"
 
+namespace cln {
+
 const cl_I mod (const cl_I& x, const cl_I& y)
 {
 // Methode:
@@ -27,3 +29,5 @@ const cl_I mod (const cl_I& x, const cl_I& y)
     }
   if (minusp(x)) { return -r; } else { return r; }
 }
+
+}  // namespace cln
