@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
@@ -13,6 +13,8 @@
 #include "cl_DS.h"
 #include "cl_low.h"
 
+namespace cln {
+
 const cl_I operator* (const cl_I& x, const cl_I& y)
 {
   // Methode:
@@ -50,3 +52,4 @@ const cl_I operator* (const cl_I& x, const cl_I& y)
 }
 // Bit complexity (x,y of length N): O(M(N)).
 
+}  // namespace cln
