@@ -4,12 +4,16 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_rational.h"
+#include "cln/rational.h"
 
 
 // Implementation.
 
+namespace cln {
+
 const cl_RA max (const cl_RA& x, const cl_RA& y)
 {
 	return (x >= y ? x : y);
 }
+
+}  // namespace cln
