@@ -4,16 +4,18 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
 
 #include "cl_R.h"
-#include "cl_float.h"
+#include "cln/float.h"
 #include "cl_F.h"
 
-const cl_F cl_float (const cl_R& x, cl_float_format_t f)
+namespace cln {
+
+const cl_F cl_float (const cl_R& x, float_format_t f)
 {
 	floatformatcase((uintL)f
 	,	return cl_R_to_SF(x);
@@ -22,3 +24,5 @@ const cl_F cl_float (const cl_R& x, cl_float_format_t f)
 	,	return cl_R_to_LF(x,len);
 	);
 }
+
+}  // namespace cln
