@@ -4,14 +4,18 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
 
 #include "cl_R.h"
-#include "cl_rational.h"
-#include "cl_float.h"
+#include "cln/rational.h"
+#include "cln/float.h"
+
+namespace cln {
 
 const cl_I floor1 (const cl_R& x)
 GEN_R_OP1_2(x, floor1, return)
+
+}  // namespace cln
