@@ -4,11 +4,13 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
 
+namespace cln {
+
 const cl_R abs (const cl_R& x)
 {
 	// Methode:
@@ -18,3 +20,5 @@ const cl_R abs (const cl_R& x)
 	else
 		return x;
 }
+
+}  // namespace cln
