@@ -1,16 +1,18 @@
-// as_cl_R().
+// cl_R_As().
 
 // General includes.
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
 
 #include "cl_N.h"
 
+namespace cln {
+
 // Cf. cl_R_p in cl_R_ring.cc.
 // But here, for better inlining in g++, it is preferrable to finish every
 // alternative with either "return cl_true;" or "return cl_false;".
@@ -32,7 +34,7 @@ inline cl_boolean cl_R_p (const cl_number& x)
 	return cl_false;
 }
 
-const cl_R& as_cl_R (const cl_number& x, const char * filename, int line)
+const cl_R& cl_R_As (const cl_number& x, const char * filename, int line)
 {
 	if (cl_R_p(x)) {
 		DeclareType(cl_R,x);
@@ -40,3 +42,5 @@ const cl_R& as_cl_R (const cl_number& x, const char * filename, int line)
 	} else
 		cl_as_error(x,"a real number",filename,line);
 }
+
+}  // namespace cln
