@@ -4,13 +4,14 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_timing.h"
+#include "cln/timing.h"
 
 
 // Implementation.
 
 #include "cl_t_config.h"
 
+
 #if defined(HAVE_GETTIMEOFDAY)
   #include <sys/time.h>
   #ifdef GETTIMEOFDAY_DOTS
@@ -20,7 +21,11 @@
   #endif
 #elif defined(HAVE_FTIME)
   #include <sys/timeb.h>
-  extern "C" int ftime (struct timeb * tp);
+  #ifdef _WIN32
+    extern "C" void ftime (struct timeb * tp);
+  #else
+    extern "C" int ftime (struct timeb * tp);
+  #endif
 #else
   #include <time.h>
 #endif
@@ -31,6 +36,8 @@
   extern "C" int perror (const char *);
 #endif
 
+namespace cln {
+
 const cl_timespec cl_current_time ()
 {
 #if defined(HAVE_GETTIMEOFDAY)
@@ -52,3 +59,5 @@ const cl_timespec cl_current_time ()
 	return cl_timespec(time(NULL),0);
 #endif
 }
+
+}  // namespace cln
