@@ -4,11 +4,13 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_timing.h"
+#include "cln/timing.h"
 
 
 // Implementation.
 
+namespace cln {
+
 const cl_timespec operator- (const cl_timespec& a, const cl_time_duration& b)
 {
 	var uintL sec = a.tv_sec - b.tv_sec;
@@ -19,3 +21,5 @@ const cl_timespec operator- (const cl_timespec& a, const cl_time_duration& b)
 	}
 	return cl_timespec(sec,nsec);
 }
+
+}  // namespace cln
