@@ -4,11 +4,13 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_timing.h"
+#include "cln/timing.h"
 
 
 // Implementation.
 
+namespace cln {
+
 const cl_time_duration operator- (const cl_timespec& a, const cl_timespec& b)
 {
 	var sintL sec = a.tv_sec - b.tv_sec;
@@ -22,3 +24,5 @@ const cl_time_duration operator- (const cl_timespec& a, const cl_timespec& b)
 	}
 	return cl_time_duration(sec,nsec);
 }
+
+}  // namespace cln
