@@ -1,14 +1,14 @@
-#include <cl_number.h>
-#include <cl_io.h>
-#include <cl_integer.h>
+#include <cln/number.h>
+#include <cln/io.h>
+#include <cln/integer.h>
 #include "cl_DS.h"
 #include "cl_2DS.h"
-#include <cl_random.h>
+#include <cln/random.h>
 #include "cl_random_impl.h"
-#include <cl_abort.h>
+#include <cln/abort.h>
 #include <stdlib.h>
 #include <string.h>
-#include <cl_timing.h>
+#include <cln/timing.h>
 
 int main (int argc, char * argv[])
 {
@@ -36,8 +36,8 @@ int main (int argc, char * argv[])
 	num_stack_alloc(b_len,b_MSDptr=,b_LSDptr=);
 	num_stack_alloc(a_len,q_MSDptr=,q_LSDptr=);
 	num_stack_alloc(a_len,q1_MSDptr=,q1_LSDptr=);
-	random_UDS(cl_default_random_state,a_MSDptr,a_len);
-	random_UDS(cl_default_random_state,b_MSDptr,b_len);
+	random_UDS(default_random_state,a_MSDptr,a_len);
+	random_UDS(default_random_state,b_MSDptr,b_len);
 	lspref(b_LSDptr,0) |= 1; // force b to be odd
 	{ CL_TIMING;
 	  for (int rep = repetitions; rep > 0; rep--)
