@@ -1,11 +1,11 @@
-#include <cl_number.h>
-#include <cl_io.h>
-#include <cl_float.h>
-#include <cl_real.h>
-#include <cl_random.h>
+#include <cln/number.h>
+#include <cln/io.h>
+#include <cln/float.h>
+#include <cln/real.h>
+#include <cln/random.h>
 #include <stdlib.h>
 #include <string.h>
-#include <cl_timing.h>
+#include <cln/timing.h>
 
 int main (int argc, char * argv[])
 {
